@@ -35,13 +35,15 @@ typedef struct _MainLoopOptions
 {
   gchar *preprocess_into;
   gboolean syntax_only;
+  gboolean config_id;
   gboolean interactive_mode;
   gboolean server_mode;
+  gboolean disable_module_discovery;
 } MainLoopOptions;
 
 extern ThreadId main_thread_handle;
-extern GCond *thread_halt_cond;
-extern GStaticMutex workers_running_lock;
+extern GCond thread_halt_cond;
+extern GMutex workers_running_lock;
 
 typedef gpointer (*MainLoopTaskFunc)(gpointer user_data);
 
@@ -59,15 +61,20 @@ main_loop_is_main_thread(void)
   return threads_equal(main_thread_handle, get_thread_id());
 }
 
+gboolean main_loop_reload_config_prepare(MainLoop *self, GError **error);
+void main_loop_reload_config_commence(MainLoop *self);
 void main_loop_reload_config(MainLoop *self);
 void main_loop_verify_config(GString *result, MainLoop *self);
+gboolean main_loop_is_terminating(MainLoop *self);
 void main_loop_exit(MainLoop *self);
 
 int main_loop_read_and_init_config(MainLoop *self);
+gboolean main_loop_was_last_reload_successful(MainLoop *self);
 void main_loop_run(MainLoop *self);
 
 MainLoop *main_loop_get_instance(void);
 GlobalConfig *main_loop_get_current_config(MainLoop *self);
+GlobalConfig *main_loop_get_pending_new_config(MainLoop *self);
 void main_loop_init(MainLoop *self, MainLoopOptions *options);
 void main_loop_deinit(MainLoop *self);
 
@@ -80,5 +87,16 @@ gboolean main_loop_initialize_state(GlobalConfig *cfg, const gchar *persist_file
 void main_loop_thread_resource_init(void);
 void main_loop_thread_resource_deinit(void);
 
+gboolean main_loop_is_control_server_running(MainLoop *self);
+
+#define MAIN_LOOP_ERROR main_loop_error_quark()
+
+GQuark main_loop_error_quark(void);
+
+enum MainLoopError
+{
+  MAIN_LOOP_ERROR_FAILED,
+  MAIN_LOOP_ERROR_RELOAD_FAILED,
+};
 
 #endif
